#!/bin/bash
# Exit immediately on error
set -eu -o pipefail

SOFTWARE=rnaseqc
VERSION=1.1.7
ARCHIVE=RNA-SeQC_v$VERSION.jar
ARCHIVE_URL=http://www.broadinstitute.org/cancer/cga/tools/rnaseqc/$ARCHIVE
SOFTWARE_DIR=${ARCHIVE/.jar/}

# Specific commands to extract and build the software
# $INSTALL_DIR and $INSTALL_DOWNLOAD have been set automatically
# $ARCHIVE has been downloaded in $INSTALL_DOWNLOAD
build() {
  mkdir -p $INSTALL_DIR/$SOFTWARE_DIR
  cp $INSTALL_DOWNLOAD/$ARCHIVE $INSTALL_DIR/$SOFTWARE_DIR/
}

module_file() {
echo "\
#%Module1.0
proc ModulesHelp { } {
  puts stderr \"\tMUGQIC - $SOFTWARE \"
}
module-whatis \"$SOFTWARE\"

set             root                $INSTALL_DIR/$SOFTWARE_DIR
setenv          RNASEQC_JAR         \$root/$ARCHIVE
"
}

# Call generic module install script once all variables and functions have been set
MODULE_INSTALL_SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
source $MODULE_INSTALL_SCRIPT_DIR/install_module.sh $@
